@@ -37,11 +37,12 @@ def add_tasks_and_process_time_middleware(new_app):
         g.request = request
         g.app = new_app
         print("url path", request.url.path, "***url", request.url)
-        context = request.scope['aws.context']
-        print('context1', context)
-        print('contect_dict1', context.__dict__)
-        print('sls sdk1', context.serverless_sdk)
-        context.serverless_sdk.set_endpoint(request.url.path)
+        if 'aws.context' in request.scope:
+            context = request.scope['aws.context']
+            # print('context1', context)
+            # print('contect_dict1', context.__dict__)
+            # print('sls sdk1', context.serverless_sdk)
+            context.serverless_sdk.set_endpoint(request.url.path)
         response = await call_next(request)
         if response.status_code == 404 and g.settings.save_calls:
             await save_not_found_from_request(request)
@@ -112,15 +113,15 @@ def create_handler(app):
             print("Lambda is warm, now!!!")
             context.serverless_sdk.set_endpoint('/warmup')
             return {}
-        print('context', context)
-        print('contect_dict', context.__dict__)
-        print('sls sdk', context.serverless_sdk)
+        # print('context', context)
+        # print('contect_dict', context.__dict__)
+        # print('sls sdk', context.serverless_sdk)
 
-        print("EVENTD", event)
+        # print("EVENTD", event)
 
         asgi_handler = Mangum(app, api_gateway_base_path=g.settings.stage)
         response = asgi_handler(event, context)
-        print('response', response)
+        # print('response', response)
         return response
 
     g.handler = handler
